# Browsers
CHROME = "chrome"
FIREFOX = "firefox"

# Configuration constants
SUPPORTED_BROWSERS = {CHROME, FIREFOX}


# Environ
TRAVIS_ENV = "SYLENIUM_TRAVIS"
